@@ -654,6 +654,13 @@ impl StructureRef {
             ))
         }
     }
+
+    #[cfg(any(feature = "v1_20", feature = "dox"))]
+    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+    #[doc(alias = "gst_structure_serialize")]
+    pub fn serialize(&self, flags: crate::SerializeFlags) -> glib::GString {
+        unsafe { from_glib_full(ffi::gst_structure_serialize(&self.0, flags.into_glib())) }
+    }
 }
 
 impl fmt::Display for StructureRef {
@@ -934,7 +941,7 @@ mod tests {
 
         let a = "Test, f1=(string)abc, f2=(uint)123;";
 
-        let s = Structure::from_str(&a).unwrap();
+        let s = Structure::from_str(a).unwrap();
         assert_eq!(s.get::<&str>("f1"), Ok("abc"));
         assert_eq!(s.get::<u32>("f2"), Ok(123));
 
@@ -949,7 +956,7 @@ mod tests {
 
         let a = None::<&Structure>.to_value();
         assert!(a.get::<Option<Structure>>().unwrap().is_none());
-        let b = Structure::from_str(&"foo").unwrap().to_value();
+        let b = Structure::from_str("foo").unwrap().to_value();
         assert!(b.get::<Option<Structure>>().unwrap().is_some());
     }
 
